package vfl;


import JSci.maths.ExtraMath;
import java.awt.*;
import java.util.*;
import java.awt.geom.*;

public class Wave implements SeaObject {

  private double height;
  private double amp;
  private double k;
  private double w;	
  private double x1;
  private double x2;
  private double time;	
  private double[] xarray;
  private double[] yarray;	
  private int resolution;
  
  public Wave (double height, double amp, double gravity, double lambda, 
               double x1, double x2, double time, int resolution) {
  	
  	
    this.height = height; 	
  	this.amp = amp;
  	k = 2.0*Math.PI/lambda;
  	w = Math.sqrt(gravity*k*ExtraMath.tanh(k*height));
  	this.x1 = x1;
  	this.x2 = x2;
  	this.time = time; 
    this.resolution = resolution;
    double pl = (x2-x1)/resolution;
    xarray = new double[resolution+1];
    yarray = new double[resolution+1];
    int i = 0;
    for (double a = x1; a<= x2;a+=pl) {
    	xarray[i] = a;
    	yarray[i] = (amp*Math.cos((k*a) - (w*time)));
    	i++;	
    }
    	 
  }	
 
  
       
  public void move (double t) {
    time += t;  	 
    double pl = (x2-x1)/resolution;
    yarray = new double[resolution+1];
    int i = 0;
    for (double a = x1; a<= x2;a+=pl) {
    	yarray[i] = (amp*Math.cos((k*a) - (w*time)));
    	i++;	
    }
  }
		
  public void moveTo (double t) {
    time = t;
    double pl = (x2-x1)/resolution;   	
    yarray = new double[resolution+1];
    int i = 0;
    for (double a = x1; a<= x2;a+=pl) {
    	yarray[i] = (amp*Math.cos((k*a) - (w*time)));
    	i++;	
    }
  	
  }
	
  public void paint(Graphics g) {
     GeneralPath gp = new GeneralPath();
     gp.moveTo((float)xarray[0], (float)(-yarray[0] + height));
     Graphics2D g2 = (Graphics2D)g;
     g2.setColor(Color.white);
     
     for (int i = 1; i <= resolution; i++) {	
     	gp.lineTo((float)xarray[i],(float)(-yarray[i] + height));
     //   g2.draw(new Line2D.Double(xarray[i],yarray[i] + height,xarray[i+1],yarray[i+1] + height));
        
    
     }
     g2.draw(gp);
  }  
 


}

