package vfl;
import JSci.maths.ExtraMath;
import java.awt.*;
import java.util.*;
import java.awt.geom.*;
import javax.swing.*;

public class DynaPressure implements SeaObject {
	private double ox;
	private int cx;
	private int sy;
	private double xfactor;
	private int yend;
	
	private double max;
	private double wd;
	private double gravity;
	private double amp;
	private double k;
	private double height;
	private double w;
	private double time;
	private double[] pressure;
	private double xnormalize;
	private double colornormalize;
	private int yjump;
	private final double linenum = 80;
	
	public DynaPressure (double cx, double wd,double gravity, double amp, double k,
	                     double height, double omega, double time,
	                     double xfactor, double yfactor, double xstart, double ystart,
	                     double xend, double ylast) {
	                     	
		double xnormalfactor = (xend - xstart) / 8.0 * xfactor;
		this.cx = (int) ((cx-xstart) * xfactor);
		this.ox = cx;
		this.wd = wd;
		this.gravity = gravity;
		this.amp = amp;
        this.k = k;
        this.w = omega;
        this.height = height;
        this.time = time;
        this.xfactor = xfactor;
        
        this.sy = (int)((-ystart-0) *yfactor);   
        this.yend = (int)((height+0)*yfactor);
        ylast *=yfactor;
        this.pressure = new double[yend+1];
        this.yjump =(int)( (ylast+sy)/ linenum);
        
        
        double ry = 0;
        double rr = height / (double)yend;
        
        this.max = 0;
        
        for (int y = 0; y<= yend; y++){ 
           pressure[y] = xfactor* wd * gravity*amp * ExtraMath.cosh (k * (-ry+height)) * 
                         Math.cos (0) / ExtraMath.cosh (k*height); 
    
           ry+=rr;
        }
        for (int i = 0; i <= yend; i++) {
        	if (max < Math.abs(pressure[i]))
        	 max = Math.abs(pressure[i]);
        }
        
        this.xnormalize = xnormalfactor / max;
	    this.colornormalize = 254.0 / max;
	    
        ry = 0;
        for (int y = 0; y<= yend; y++){ 
           pressure[y] = xfactor* wd * gravity*amp * ExtraMath.cosh (k * (-ry+height)) * 
                         Math.cos ((k*ox) - (w*time)) / ExtraMath.cosh (k*height); 
    
           ry+=rr;
        }	
        

	
	}
	                     
	public void drawLegend (Graphics g, int width, int height) {
	   g.setColor(Color.white);
	   int hm = (int)Math.round(height/15.0);
	   int valueinc = (int)((max/xfactor) / (hm-1));
	   double cn = 254/(max/xfactor);
	   int valueint = 0;
	   String value;
	   for (int i = 1 ; i <= hm ; i++) {
	   	  value = String.valueOf(valueint);
	      g.setColor(Color.white);
	   	  g.drawString(value,3,i*15);
	   	  g.setColor ( new Color (255-(int)(Math.abs(valueint*cn)),
              						   (int)(Math.abs(valueint*cn)),0));
          g.drawLine((int)(width/1.75),(i*15)-5, width - 7, (i*15)-5);   
	   	  valueint +=valueinc;
	   }	
	}
		
	
    public void move(double t) {
        this.time = this.time + t;
     	double ry = 0;
        double rr = height / (double)yend;
        for (int y = 0; y<= yend; y++){ 
           pressure[y] = xfactor* wd * gravity*amp * ExtraMath.cosh (k * (-ry+height)) * 
                         Math.cos ((k*ox) - (w*time)) / ExtraMath.cosh (k*height); 
           ry+=rr;
        }	
    }
    
    
    public void moveTo(double t) {
    	this.time = t;
     	double ry = 0;
        double rr = height / (double)yend;
        for (int y = 0; y<= yend; y++){ 
           pressure[y] = xfactor* wd * gravity*amp * ExtraMath.cosh (k * (-ry+height)) * 
                         Math.cos ((k*ox) - (w*time)) / ExtraMath.cosh (k*height); 
           ry+=rr;
        }
	}
    public void paint(Graphics g) {
    	
    	GeneralPath gp = new GeneralPath();
        gp.moveTo((float)(pressure[0]*xnormalize)+cx, (float)(sy));
        Graphics2D g2 = (Graphics2D)g;
        
       
        int gc = 0;
        for (int i = 1; i <= yend; i++) {
            gp.lineTo((float)((pressure[i]*xnormalize)+cx),(float)i+sy);
            
            if ((i % yjump) == 0) {
              g2.setColor ( new Color (255-(int)(Math.abs(pressure[i]*colornormalize)),
              						   (int)(Math.abs(pressure[i]*colornormalize)),0));
              						   
              g2.drawLine(cx,i+sy,(int)((pressure[i]*xnormalize)+cx),i+sy);
            }
            
            //g.fillOval((int)Math.round(pressure[i]+cx),(int)i+sy,1,1);	
        	//g.fillOval(i+cx,(int)i+sy,1,1);	

        }
        g2.setColor(Color.gray);  
        g2.draw(gp);
        //g2.setColor(Color.orange);
        g2.drawLine(cx,sy, cx, yend+sy);
    	
    	
   }

	
}
