package vfl;


import JSci.maths.ExtraMath;
import java.awt.*;
import java.util.*;
import java.awt.geom.*;

public class Wave implements SeaObject {
    
    private double ystart;
    private double amp;
    private double k;
    private double w;
    private int x1;
    private int x2;
    private double time;
    private double[] xarray;
    private double[] yarray;
    private int resolution;
    
    public Wave(double height, double amp, double gravity, double lambda,
    double x1, double x2, double time,
    double xfactor, double yfactor,double ystart) {
        
        
        this.ystart = yfactor*ystart;
        this.amp = yfactor*amp;
        amp *= yfactor;
        
        this.x1 = (int) Math.round(x1*xfactor);
        this.x2 = (int) Math.round(((x2-x1)*xfactor)+this.x1);
        this.resolution = this.x2-this.x1;
        
        
        k = 2.0*Math.PI/(lambda);
        w = Math.sqrt(gravity*k*ExtraMath.tanh(k*height));
        
        k /= xfactor;
        
        
        
        this.time = time;
        xarray = new double[resolution+1];
        yarray = new double[resolution+1];
        int i = 0;
        for (double a = this.x1; a<= this.x2;a+=1) {
            xarray[i] = a;
            yarray[i] = (amp*Math.cos((k*a) - (w*time)));
            i++;
        }
        
        
    }
    
    
    
    public void move(double t) {
        time += t;
        //yarray = new double[resolution+1];
        int i = 0;
        for (double a = x1; a<= x2;a+=1) {
            yarray[i] = (amp*Math.cos((k*a) - (w*time)));
            i++;
        }
    }
    
    public void moveTo(double t) {
        time = t;
        //yarray = new double[resolution+1];
        int i = 0;
        for (double a = x1; a<= x2;a+=1) {
            yarray[i] = (amp*Math.cos((k*a) - (w*time)));
            i++;
        }
        
    }
    
    public double[] getY () {
    	return yarray;
    }
    
    public void paint(Graphics g) {
        GeneralPath gp = new GeneralPath();
        gp.moveTo((float)xarray[0]-x1, (float)(-yarray[0] - ystart));
        Graphics2D g2 = (Graphics2D)g;
        g2.setColor(Color.white);
        
        for (int i = 1; i <= resolution; i++) {
            gp.lineTo((float)xarray[i]-x1,(float)(-yarray[i] - ystart));
        }
        g2.draw(gp);
    }
    
    
    
}

